==> paymentplugins-java-1.0.0-sources.jar: com/paymentplugins/Http.java <==
package com.paymentplugins;

import java.io.BufferedInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.HttpURLConnection;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.Base64;
import javax.xml.bind.DatatypeConverter;

public class Http {

	private Configuration config;
	
	public static enum Method{
		
		GET("GET"), POST("POST");
		
		private String method;
		
		private Method(String method){
			this.method = method;
		}
		
		public String getMethod(){
			return this.method;
		}
	}
	
	public static interface HTTP_CODE{
		
		public int getCode();
		
		public String getMessage();
	}
	
	public static enum Success implements HTTP_CODE{

		SC_OK(200, "OK"), SC_CREATED(201, "Created"), SC_ACCEPTED(202, "Accepted"), 
		SC_NON_AUTHORITATIVE_INFORMATION(203, "Non Authoritative Information"), SC_NO_CONTENT(204, "No Content");
		
		private int code;
		private String message;
		
		private Success(int code, String message){
			this.code = code;
			this.message = message;
		}
	
		public int getCode() {
			return this.code;
		}

		public String getMessage() {
			return this.message;
		}
		
	};
	
	public static enum Error implements HTTP_CODE{

		SC_BAD_REQUEST(400, "Bad Request"), SC_UNAUTHORIZED(401, "Unauthorized "), SC_FORBIDDEN(403, "Forbidden"), 
		SC_NOT_FOUND(404, "Not Found"), SC_METHOD_NOT_ALLOWED(405, "Method Not Allowed"),
		SC_INTERNAL_SERVER_ERROR(500, "Server Error"), SC_NOT_IMPLEMENTED(501, "Not Implemented"), SC_BAD_GATEWAY(502, "Bad Gateway"), 
		SC_SERVICE_UNAVAILABLE(503, "Service Unavailable"), SC_GATEWAY_TIMEOUT(504, "Gateway Timeout");
		
		private int code;
		private String message;
		
		private Error(int code, String message){
			this.code = code;
			this.message = message;
		}
	
		public int getCode() {
			return this.code;
		}

		public String getMessage() {
			return this.message;
		}
		
	};
	
	public Http(Configuration config){
		this.config = config;
	}
	
	public XMLNode processRequest(String uri, Method method){
		return processRequest(uri, method, null);
	}
	
	/**
	 * Process the request
	 * @param uri - The Uri associated with the specific http call.
	 * @param method - Request type. GET, POST, PUT, DELETE.
	 * @param body - Request body to be sent to the target. 
	 * @return Returns an instance of XMLNode containing objects parsed from the XML response body.
	 */
	public XMLNode processRequest(String uri, Method method, String body){
		
		StringBuilder builder = new StringBuilder();
		HttpURLConnection connection = null;
		XMLNode node = null;
		try {
			connection = this.buildConnection(uri, method.getMethod());
			if(body != null){
				connection.getOutputStream().write(body.getBytes());
			}
			int httpCode = connection.getResponseCode();
			this.checkResponseCode(httpCode);
			InputStream stream = connection.getInputStream();
			BufferedInputStream buff = new BufferedInputStream(stream);
			int i;
			while((i = buff.read()) != -1){
				builder.append((char)i);
			}
			node = SimpleXMLNode.parse(builder.toString());
		} catch (IOException e) {
			throw new PaymentPluginsException(e.getMessage());
		} catch(Exception e){
			throw new PaymentPluginsException(e.getMessage());
		}
		finally{
			if(connection != null){
				connection.disconnect();
			}
		}
		return node;
	}

	private HttpURLConnection buildConnection(String uri, String method) throws Exception{
		HttpURLConnection connection = null;
		String url = this.config.getBaseUrl() + uri;
		try {
			URL connectionUrl = new URL(url);
			connection = (HttpURLConnection)connectionUrl.openConnection();
			connection.setRequestMethod(method);
			connection.addRequestProperty("Authorization", getAuthorizationHeader());
			connection.addRequestProperty("Content-Type", "application/json");
			connection.addRequestProperty("Accept", "application/xml");
			connection.setDoOutput(true);
			connection.setConnectTimeout(60000);
		} catch (MalformedURLException e) {
			throw new Exception("MalformedURLException: " + e.getMessage());
		} catch(IOException e){
			throw new Exception("IOException: " + e.getMessage());
		} 
		return connection;
	}
	
	private String getAuthorizationHeader() {
	    byte[] auths = (this.config.getPublickey()+":"+this.config.getPrivatekey()).getBytes();
	    String authorizations = DatatypeConverter.printBase64Binary(auths);
		//String authorizations = Base64.getEncoder().encodeToString(auths);
		String authHeader = String.format("Basic %s", authorizations);
		return authHeader;
	}
	
	private void checkResponseCode(int httpCode){
		HTTP_CODE codeType;
		if((codeType = isResponseCodeError(httpCode)) != null){
			throw new HttpResponseException(codeType.getMessage());
		}
	}
	
	private HTTP_CODE isResponseCodeError(int httpCode){
		for(Error error : Error.values()){
			if(error.getCode() == httpCode){
				return error;
			}
		}
		return null;
	}
}

==> paymentplugins-java-1.0.2-sources.jar: com/paymentplugins/Http.java <==
package com.paymentplugins;

import java.io.BufferedInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.HttpURLConnection;
import java.net.MalformedURLException;
import java.net.URL;
import java.security.KeyStore;
import java.security.NoSuchAlgorithmException;
import java.security.Principal;
import java.security.SecureRandom;
import java.security.cert.CertificateFactory;
import java.security.cert.X509Certificate;
import java.util.Collection;

import javax.net.ssl.HttpsURLConnection;
import javax.net.ssl.KeyManagerFactory;
import javax.net.ssl.SSLContext;
import javax.net.ssl.SSLSocket;
import javax.net.ssl.SSLSocketFactory;
import javax.net.ssl.TrustManagerFactory;

import java.security.cert.Certificate;
import javax.xml.bind.DatatypeConverter;

public class Http {

	private Configuration config;
	private static double JAVA_VERSION = getJavaVersion();
	
	public static enum Method{
		
		GET("GET"), POST("POST");
		
		private String method;
		
		private Method(String method){
			this.method = method;
		}
		
		public String getMethod(){
			return this.method;
		}
	}
	
	public static interface HTTP_CODE{
		
		public int getCode();
		
		public String getMessage();
	}
	
	public static enum Success implements HTTP_CODE{

		SC_OK(200, "OK"), SC_CREATED(201, "Created"), SC_ACCEPTED(202, "Accepted"), 
		SC_NON_AUTHORITATIVE_INFORMATION(203, "Non Authoritative Information"), SC_NO_CONTENT(204, "No Content");
		
		private int code;
		private String message;
		
		private Success(int code, String message){
			this.code = code;
			this.message = message;
		}
	
		public int getCode() {
			return this.code;
		}

		public String getMessage() {
			return this.message;
		}
		
	};
	
	public static enum Error implements HTTP_CODE{

		SC_BAD_REQUEST(400, "Bad Request"), SC_UNAUTHORIZED(401, "Unauthorized "), SC_FORBIDDEN(403, "Forbidden"), 
		SC_NOT_FOUND(404, "Not Found"), SC_METHOD_NOT_ALLOWED(405, "Method Not Allowed"),
		SC_INTERNAL_SERVER_ERROR(500, "Server Error"), SC_NOT_IMPLEMENTED(501, "Not Implemented"), SC_BAD_GATEWAY(502, "Bad Gateway"), 
		SC_SERVICE_UNAVAILABLE(503, "Service Unavailable"), SC_GATEWAY_TIMEOUT(504, "Gateway Timeout");
		
		private int code;
		private String message;
		
		private Error(int code, String message){
			this.code = code;
			this.message = message;
		}
	
		public int getCode() {
			return this.code;
		}

		public String getMessage() {
			return this.message;
		}
		
	};
	
	public Http(Configuration config){
		this.config = config;
	}
	
	public XMLNode processRequest(String uri, Method method){
		return processRequest(uri, method, null);
	}
	
	/**
	 * Process the request
	 * @param uri - The Uri associated with the specific http call.
	 * @param method - Request type. GET, POST, PUT, DELETE.
	 * @param body - Request body to be sent to the target. 
	 * @return Returns an instance of XMLNode containing objects parsed from the XML response body.
	 */
	public XMLNode processRequest(String uri, Method method, String body){
		
		StringBuilder builder = new StringBuilder();
		HttpURLConnection connection = null;
		XMLNode node = null;
		try {
			connection = this.buildConnection(uri, method.getMethod());
			if(connection instanceof HttpsURLConnection){
				((HttpsURLConnection) connection).setSSLSocketFactory(generateSSLSocketFactory());
			}
			if(body != null){
				connection.getOutputStream().write(body.getBytes());
			}
			int httpCode = connection.getResponseCode();
			this.checkResponseCode(httpCode);
			InputStream stream = connection.getInputStream();
			BufferedInputStream buff = new BufferedInputStream(stream);
			int i;
			while((i = buff.read()) != -1){
				builder.append((char)i);
			}
			node = SimpleXMLNode.parse(builder.toString());
		} catch (IOException e) {
			throw new PaymentPluginsException(e.getMessage());
		} catch(Exception e){
			throw new PaymentPluginsException(e.getMessage());
		}
		finally{
			if(connection != null){
				connection.disconnect();
			}
		}
		return node;
	}

	/**
	 * Add the api certs to the java keystore to ensure the handshake between servers is successful. 
	 * @return SSLSocketFactory
	 */
	private SSLSocketFactory generateSSLSocketFactory() {
		String certPath = this.config.getCert();
		InputStream certStream = null;
		ClassLoader cl = Http.class.getClassLoader();
		certStream = cl.getResourceAsStream(certPath);
		SSLSocketFactory sf = null;
		try{
			KeyStore keyStore = KeyStore.getInstance(KeyStore.getDefaultType());
			keyStore.load(null);
			CertificateFactory cf = CertificateFactory.getInstance("X.509");
			Collection<? extends Certificate> collection = cf.generateCertificates(certStream);
			for(Certificate cert : collection){
				if(cert instanceof X509Certificate){
					Principal principal = ((X509Certificate) cert).getSubjectX500Principal();
					String alias = principal.getName();
					keyStore.setCertificateEntry(alias, cert);
				}
			}
			KeyManagerFactory kmf = KeyManagerFactory.getInstance(KeyManagerFactory.getDefaultAlgorithm());
			kmf.init(keyStore, null);
			TrustManagerFactory tmf = TrustManagerFactory.getInstance(TrustManagerFactory.getDefaultAlgorithm());
			tmf.init(keyStore);
			SSLContext sslContext = null;
			sslContext = this.getSSLContext();
			sslContext.init(kmf.getKeyManagers(), tmf.getTrustManagers(), new SecureRandom());
			sf = sslContext.getSocketFactory();
		}catch(Exception e){
			throw new PaymentPluginsException(e.getMessage());
		}
		finally{
			if(certStream != null){
				try {
					certStream.close();
				} catch (IOException e) {
					throw new PaymentPluginsException(e.getMessage());
				}
			}
		}
		return sf;
	}

	private HttpURLConnection buildConnection(String uri, String method) throws Exception{
		HttpURLConnection connection = null;
		String url = this.config.getBaseUrl() + uri;
		try {
			URL connectionUrl = new URL(url);
			connection = (HttpURLConnection)connectionUrl.openConnection();
			connection.setRequestMethod(method);
			connection.addRequestProperty("Authorization", getAuthorizationHeader());
			connection.addRequestProperty("Content-Type", "application/json");
			connection.addRequestProperty("Accept", "application/xml");
			connection.setDoOutput(true);
			connection.setConnectTimeout(60000);
		} catch (MalformedURLException e) {
			throw new Exception("MalformedURLException: " + e.getMessage());
		} catch(IOException e){
			throw new Exception("IOException: " + e.getMessage());
		} 
		return connection;
	}
	
	private SSLContext getSSLContext() throws NoSuchAlgorithmException{
		SSLContext sslContext = null;
		if(JAVA_VERSION < 1.7){
			sslContext = SSLContext.getInstance("TLSv1.1");
		}
		else{
			sslContext = SSLContext.getInstance("TLSv1.2");
		}
		return sslContext;
	}
	
	private String getAuthorizationHeader() {
	    byte[] auths = (this.config.getPublickey()+":"+this.config.getPrivatekey()).getBytes();
	    String authorizations = DatatypeConverter.printBase64Binary(auths);
		//String authorizations = Base64.getEncoder().encodeToString(auths);
		String authHeader = String.format("Basic %s", authorizations);
		return authHeader;
	}
	
	private void checkResponseCode(int httpCode){
		HTTP_CODE codeType;
		if((codeType = isResponseCodeError(httpCode)) != null){
			throw new HttpResponseException(codeType.getMessage());
		}
	}
	
	private HTTP_CODE isResponseCodeError(int httpCode){
		for(Error error : Error.values()){
			if(error.getCode() == httpCode){
				return error;
			}
		}
		return null;
	}
	
	private static double getJavaVersion(){
		String version = System.getProperty("java.version");
		double v = 0;
		if(version.startsWith("1.8")){
			v = 1.8;
		}
		else if(version.startsWith("1.7")){
			v = 1.7;
		}
		else if(version.startsWith("1.6")){
			v = 1.6;
		}
		else if(version.startsWith("1.5")){
			v = 1.5;
		}
		return v;
	}
}
